package VMOMI::HostFirewallRuleset;
use parent 'VMOMI::DynamicData';

use strict;
use warnings;

our @class_ancestors = ( 
    'DynamicData',
);

our @class_members = ( 
    ['key', undef, 0, ],
    ['label', undef, 0, ],
    ['required', 'boolean', 0, ],
    ['rule', 'HostFirewallRule', 1, ],
    ['service', undef, 0, 1],
    ['enabled', 'boolean', 0, ],
    ['allowedHosts', 'HostFirewallRulesetIpList', 0, 1],
);

sub get_class_ancestors {
    return @class_ancestors;
}

sub get_class_members {
    my $class = shift;
    my @super_members = $class->SUPER::get_class_members();
    return (@super_members, @class_members);
}

1;
